@@ -6,4 +6,4 @@ class TopicFilter(Filter):
     '''
 
     def __init__(self):
-        super().__init__('text-davinci-002', 'message that discusses one-word system components')
\ No newline at end of file
+        super().__init__('message that discusses one-word system components')
\ No newline at end of file
