@@ -24,6 +24,16 @@ class ExtractMenuItemsModel:
         self.examples = examples
 
     def predict(self, conversation):
+        """
+        Parameters
+        ----------
+        conversation : str
+            Transcript of conversation of customer ordering from restaurant
+
+        Returns
+        -------
+        str : The extracted menu items from the conversation
+        """
         prompt = {
             "{{examples}}": "\n\n".join(["CONVERSATION:\n" + example["conversation"] + "\nORDER:\n" + example["order"] for example in self.examples]),
             "{{input}}": conversation
