@@ -32,6 +32,14 @@ class FilterTopicsModel:
         logging.set_verbosity(40)
 
     def fit(self, topics, topic_type):
+        """
+        Parameters
+        ----------
+        topics : list[str]
+            A list of potential topics to be filtered
+        topic_type : str
+            A broad categorization of the context that should be used to get the topics (e.g. "tech", "finance")
+        """
         self.topic_type = topic_type
         self.topics = topics
         # Subdivide topics array
@@ -49,6 +57,11 @@ class FilterTopicsModel:
             self.topics_array_split.append(curr)
 
     def predict(self):
+        """
+        Returns
+        ----------
+        lst : A subset of the topics that are relevant to the topic area.
+        """
         # If get_topics has been called on the same messages array
         # Then use the previous results
         hash_docs = hash(frozenset(self.topics))
