@@ -18,12 +18,27 @@ class QuestionAnswerModel:
             lesson: str,
             answer: str,
             examples: list[str]):
+        """
+        Parameters
+        ----------
+        lesson : str
+            The broader context where the question is being asked
+        answer : str
+            The correct answer for the questions
+        examples : list[str]
+            A list of questions which correspond to the answer
+        """
         self.lesson = lesson
         self.question_count = str(len(examples) + 1)
         self.answer = answer
         self.examples = examples
 
     def predict(self):
+        """
+        Returns
+        -------
+        str : A question for which the answer is the answer the model if fitted to.
+        """
         examples_string = "\n".join(
             [f'{i + 1}. ' + example for i, example in enumerate(self.examples)])
         prompt = {
